%global pypi_name collectd-rabbitmq
%if 0%{?rhel} && 0%{?rhel} < 8
%global with_python2 1
%global with_python3 0
%else
%global with_python2 0
%global with_python3 1
%endif

Name:           %{pypi_name}
Version:        1.21.0
Release:        2%{?dist}
Summary:        A collectd plugin to collect statistics from RabbitMQ

License:        ASL 2.0
URL:            https://github.com/NYTimes/collectd-rabbitmq
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        collectd-rabbitmq.conf
BuildArch:      noarch

# Fix the Sphinx themes path.
Patch10:         collectd-rabbitmq-doc-theme-path.patch

BuildRequires:  python2-devel
BuildRequires:  python2-setuptools
BuildRequires:  python2-mock
%if %{with_python2}
BuildRequires:  python2-sphinx
BuildRequires:  python2-sphinx-theme-alabaster
BuildRequires:  pytest
%endif
%if %{with_python3}
# https://github.com/nytimes/collectd-rabbitmq/pull/76
Patch11:        https://github.com/nytimes/collectd-rabbitmq/commit/4312b277bfc4767ae01f449ff6c5b4a8f79dc046.patch
BuildRequires:  python3-sphinx
BuildRequires:  python3-sphinx-theme-alabaster
BuildRequires:  python3-pytest
%endif

%description
%{summary}.

Documentation: https://collectd-rabbitmq.readthedocs.org.


%if %{with_python2}
%package -n     python2-%{pypi_name}
Summary:        %{summary}
Requires:       collectd
# On EPEL 7 collectd-python is included in the main collectd package
Requires:       %{pypi_name}-data = %{version}-%{release}
%{?python_provide:%python_provide python2-%{pypi_name}}

%description -n python2-%{pypi_name}
%{summary}.

Documentation: https://collectd-rabbitmq.readthedocs.org.
%endif

%if %{with_python3}
%package -n     python3-%{pypi_name}
Summary:        %{summary}
Requires:       collectd
Requires:       collectd-python
Requires:       %{pypi_name}-data = %{version}-%{release}
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n python3-%{pypi_name}
%{summary}.

Documentation: https://collectd-rabbitmq.readthedocs.org.
%endif


%package -n %{pypi_name}-data
Summary:        Data files for collectd-rabbitmq
Requires:       collectd

%description -n %{pypi_name}-data
Data files (TypesDB) for collectd-rabbitmq


%package -n %{pypi_name}-doc
Summary:       Documentation for collectd-rabbitmq

%description -n %{pypi_name}-doc
Documentation for collectd-rabbitmq


%prep
%autosetup -n %{pypi_name}-%{version} -p1
# Remove bundled egg-info
rm -rf %{pypi_name}.egg-info


%build
%if %{with_python2}
%py2_build
%endif
%if %{with_python3}
%py3_build
%endif

# generate html docs
PYTHONPATH=${PWD} sphinx-build docs html
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}

%install
%if %{with_python2}
%py2_install
%endif
%if %{with_python3}
%py3_install
%endif

mkdir -p %{buildroot}%{_datadir}/collectd/
mv %{buildroot}%{_datadir}/collectd-rabbitmq/types.db.custom %{buildroot}%{_datadir}/collectd/rabbitmq-types.db
install -D -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/collectd.d/rabbitmq.conf
cat > %{buildroot}%{_sysconfdir}/collectd.d/rabbitmq-data.conf << EOF
TypesDB "%{_datadir}/collectd/rabbitmq-types.db"
EOF
touch --reference %{buildroot}%{_sysconfdir}/collectd.d/rabbitmq.conf %{buildroot}%{_sysconfdir}/collectd.d/rabbitmq-data.conf

%check
%if %{with_python2}
%{__python2} -m pytest
%endif
%if %{with_python3}
%{__python3} -m pytest
%endif

%if %{with_python2}
%files -n python2-%{pypi_name}
%license LICENSE
%doc docs/readme.rst README.rst
%{python2_sitelib}/collectd_rabbitmq
%{python2_sitelib}/collectd_rabbitmq-%{version}-py?.?.egg-info
%endif

%if %{with_python3}
%files -n python3-%{pypi_name}
%license LICENSE
%doc docs/readme.rst README.rst
%{python3_sitelib}/collectd_rabbitmq
%{python3_sitelib}/collectd_rabbitmq-%{version}-py?.?.egg-info
%endif

%files -n %{pypi_name}-data
%license LICENSE
%{_datadir}/collectd/rabbitmq-types.db
%config(noreplace) %{_sysconfdir}/collectd.d/rabbitmq.conf
%config(noreplace) %{_sysconfdir}/collectd.d/rabbitmq-data.conf

%files -n %{pypi_name}-doc
%doc html
%license LICENSE

%changelog
* Tue Jun 30 2020 Aurelien Bompard <abompard@fedoraproject.org> - 1.21.0-2
- Build for Python 3 on EPEL8

* Fri Feb 14 2020 Aurelien Bompard <abompard@fedoraproject.org> - 1.21.0-1
- Version 1.21.0
- Support EPEL8

* Mon Aug 05 2019 Aurelien Bompard <abompard@fedoraproject.org> - 1.20.0-1
- Initial package.
